diff scripts/plot/colorbar.m @ 11576:8ac9687dbe9f

rename backend to graphics_toolkit
author John W. Eaton <jwe@octave.org>
date Thu, 20 Jan 2011 02:29:57 -0500
parents fd0a3ac60b0e
children c792872f8942
line wrap: on
line diff
--- a/scripts/plot/colorbar.m
+++ b/scripts/plot/colorbar.m
@@ -107,8 +107,8 @@
 
   if (! deleting)
     ## FIXME - Matlab does not require the "position" property to be active.
     ##         Is there a way to determine the plotbox position for the gnuplot
     ##         backend with the outerposition is active?
     set (ax, "activepositionproperty", "position");
     obj = get (ax);
     obj.__my_handle__ = ax;
@@ -274,7 +274,7 @@
     else
       scale = [scale, 1];
     endif
-    if (strcmp (get (cf, "__backend__"), "gnuplot")
+    if (strcmp (get (cf, "__graphics_toolkit__"), "gnuplot")
         && strcmp (obj.activepositionproperty, "outerposition"))
       obj.outerposition = obj.outerposition .* [1, 1, scale];
       off = 0.5 * (obj.outerposition (3:4) - __actual_axis_position__ (obj)(3:4));
@@ -107,8 +107,8 @@
   if (! deleting)
     ## FIXME - Matlab does not require the "position" property to be active.
-    ##         Is there a way to determine the plotbox position for the gnuplot
-    ##         backend with the outerposition is active?
+    ##         Is there a way to determine the plotbox position for the
+    ##         gnuplot graphics toolkit with the outerposition is active?
     set (ax, "activepositionproperty", "position");
     obj = get (ax);